# CodegenPipelineRunDetail

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**id** | **str** |  | [optional] 
**name** | **str** |  | [optional] 
**namespace** | **str** |  | [optional] 
**pipeline_id** | **str** |  | [optional] 
**experiment_id** | **str** |  | [optional] 
**recurring_job_id** | **str** |  | [optional] 
**status** | **str** |  | [optional] 
**created_at** | **datetime** |  | [optional] 
**scheduledd_at** | **datetime** |  | [optional] 
**finished_at** | **datetime** |  | [optional] 
**pipeline_name** | **str** |  | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


